<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="zh_CN">
<context>
    <name>PluginItem</name>
    <message>
        <location filename="../pluginitem.cpp" line="89"/>
        <source>Remove from dock</source>
        <translation>移除驻留</translation>
    </message>
</context>
<context>
    <name>QuickPluginItem</name>
    <message>
        <location filename="../quickpluginitem.cpp" line="160"/>
        <source>Remove from dock</source>
        <translation>在任务栏上移除</translation>
    </message>
    <message>
        <location filename="../quickpluginitem.cpp" line="160"/>
        <source>Pin to dock</source>
        <translation>在任务栏上驻留</translation>
    </message>
</context>
</TS>